# $Id: Loandesk.pm 31375 2010-06-22 13:48:29Z wsl $
# $URL: https://infix.uvt.nl/its-id/trunk/sources/loandesk/lib/UvT/Loandesk.pm $

use utf8;
use strict;
use warnings FATAL => 'all';

package UvT::Loandesk;

use UvT::Loandesk::Mainpage;
use UvT::Loandesk::Reserve;
use UvT::Loandesk::Order;

use Xyzzy -Base;

field 'secret', -init => 'die "no LoandeskSecret configured\n"';
field 'mps', -init => 'die "no LoandeskMPS configured\n"';
field 'app_id', -init => 'die "no LoandeskAselectID configured\n"';
field 'nonce_timeout' => 300;

field 'ldap_server' => 'ldap://localhost';
field 'ldap_base', -init => 'die "no LDAPBase configured\n"';
field 'ldap_filter';
field 'ldap_attribute' => 'uid';

*set_loandesksecret = *secret;
*set_loandeskmps = *mps;
*set_loandeskaselectid = *app_id;

*set_ldapserver = *ldap_server;
*set_ldapbase = *ldap_base;
*set_ldapfilter = *ldap_filter;
*set_ldapattribute = *ldap_attribute;

our %units = (
	'' => 1,
	s => 1,
	m => 60,
	h => 3600,
	d => 86400,
	w => 604800,
	m => 31 * 86400,
	q => 92 * 86400,
	y => int(364.2425 * 86400),
);

sub parse_timeout {
	my ($time) = @_;
	$time =~ /^(\d+)\s*([a-z]?)$/i;
	my ($seconds, $unit) = ($1, $2);
	die "can't parse time value '$time'"
		unless defined $seconds;
	$unit = $units{lc $unit};
	die "unknown unit $unit\n"
		unless defined $unit;
	return $seconds * $unit;
}


sub set_loandesknoncetimeout {
	eval { $self->nonce_timeout($self->parse_timeout(@_)) };
	warn "LoandeskTimeout: $@" if $@;
}

our %generators = (
	'' => 'UvT::Loandesk::Mainpage',
	'reserve' => 'UvT::Loandesk::Reserve',
	'order' => 'UvT::Loandesk::Order',
);

sub generators { \%generators }
